from data_manipulation import (
    base,
    beautifulsoup_,
    django_,
    geopandas_,
    mysql_connector_python_,
    pandas_,
    psycopg2_,
    pyspark_,
)

from . import _version

__version__ = _version.get_versions()["version"]
